@@ -1,4 +1,4 @@
-//@line 39 "/home/karma/src/build/browser/base/content/aboutDialog.js"
+//@line 39 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
 
 // Services = object with smart getters for common XPCOM services
 Components.utils.import("resource://gre/modules/Services.jsm");
@@ -28,24 +28,26 @@ function init(aEvent)
     // Pref is unset
   }
 
-  // Include the build ID if this is a "pre" (i.e. non-release) build
+  // Include the build ID if this is an "a#" (nightly or aurora) build
   let version = Services.appinfo.version;
-  if (version.indexOf("pre") != -1) {
+  if (/a\d+$/.test(version)) {
     let buildID = Services.appinfo.appBuildID;
     let buildDate = buildID.slice(0,4) + "-" + buildID.slice(4,6) + "-" + buildID.slice(6,8);
     document.getElementById("version").value += " (" + buildDate + ")";
   }
 
-//@line 86 "/home/karma/src/build/browser/base/content/aboutDialog.js"
+//@line 86 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
 
-//@line 88 "/home/karma/src/build/browser/base/content/aboutDialog.js"
+//@line 88 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
   gAppUpdater = new appUpdater();
-//@line 90 "/home/karma/src/build/browser/base/content/aboutDialog.js"
+//@line 90 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
 
-//@line 96 "/home/karma/src/build/browser/base/content/aboutDialog.js"
+  gChannelSelector.init();
+
+//@line 98 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
 }
 
-//@line 99 "/home/karma/src/build/browser/base/content/aboutDialog.js"
+//@line 101 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
 Components.utils.import("resource://gre/modules/AddonManager.jsm");
@@ -307,7 +309,6 @@ appUpdater.prototype =
       // notified with the normal app update user interface so this is safe.
       gAppUpdater.isChecking = false;
       gAppUpdater.selectPanel("noUpdatesFound");
-      return;
     },
 
     /**
@@ -521,3 +522,72 @@ appUpdater.prototype =
     return this;
   }
 };
+//@line 576 "/home/karma/src/firefox5/build/browser/base/content/aboutDialog.js"
+
+var gChannelSelector = {
+  // Disable this UI entirely for now by not including any valid channels
+  validChannels: {},
+  
+  init: function() {
+    try {
+      this.channelValue = Services.prefs.getCharPref("app.update.desiredChannel");
+    } catch (e) {
+      let defaults = Services.prefs.getDefaultBranch("");
+      this.channelValue = defaults.getCharPref("app.update.channel");
+    }
+
+    // Only show channel selector UI on valid update channels.
+    if (this.channelValue in this.validChannels) {
+      document.getElementById("currentChannelText").hidden = false;
+      this.setChannelLabel(this.channelValue);
+      this.setChannelMenuitem(this.channelValue);
+    }
+  },
+
+  selectChannel: function(aSelectedItem) {
+    document.getElementById("channelDescriptionDeck").selectedPanel =
+      document.getElementById(aSelectedItem.value + "Description");
+  },
+
+  cancel: function() {
+    this.setChannelMenuitem(this.channelValue);
+    this.hide();
+  },
+
+  apply: function() {
+    this.channelValue = document.getElementById("channelMenulist").selectedItem.value;
+    this.setChannelLabel(this.channelValue);
+
+    // Change app update channel.
+    Services.prefs.setCharPref("app.update.desiredChannel", this.channelValue);
+
+    // Stop any downloads in progress
+    gAppUpdater.aus.pauseDownload();
+    // App updater will look at app.update.desiredChannel for new channel value
+    // and will clear it when the update is complete.
+    gAppUpdater.isChecking = true;
+    gAppUpdater.checker.checkForUpdates(gAppUpdater.updateCheckListener, true);
+
+    this.hide();
+  },
+
+  show: function() {
+    document.getElementById("contentDeck").selectedPanel =
+      document.getElementById("channelSelector");
+  },
+
+  hide: function() {
+    document.getElementById("contentDeck").selectedPanel =
+      document.getElementById("detailsBox");  
+  },
+
+  setChannelLabel: function(aValue) {
+    let channelLabel = document.getElementById("currentChannel");
+    channelLabel.value = document.getElementById(aValue + "Menuitem").label;
+  },
+
+  setChannelMenuitem: function(aValue) {
+    document.getElementById("channelMenulist").selectedItem =
+      document.getElementById(aValue + "Menuitem");
+  }
+}
