@@ -1,14 +1,12 @@
-//@line 37 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 37 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 41 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
-//@line 44 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 44 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
-//@line 50 "/home/karma/src/build/browser/app/profile/firefox.js"
-
-pref("general.startup.browser", true);
+//@line 50 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 pref("browser.chromeURL","chrome://browser/content/");
 pref("browser.hiddenWindowChromeURL", "chrome://browser/content/hiddenWindow.xul");
@@ -184,9 +182,9 @@ pref("general.useragent.locale", "ja");
 pref("general.skins.selectedSkin", "classic/1.0");
 
 pref("general.smoothScroll", false);
-//@line 228 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 226 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 232 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 230 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -215,11 +213,11 @@ pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
 pref("browser.overlink-delay", 70);
 
-//@line 261 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 259 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 266 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 264 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 270 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 268 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
 // 0: Match anywhere (e.g., middle of words)
 // 1: Match on word boundaries and then try matching anywhere
@@ -263,9 +261,9 @@ pref("browser.download.saveLinkAsFilenameTimeout", 1000);
 
 pref("browser.download.useDownloadDir", true);
 
-//@line 317 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 315 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.download.folderList", 1);
-//@line 319 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 317 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.download.manager.showAlertOnComplete", true);
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 2);
@@ -323,9 +321,9 @@ pref("browser.link.open_newwindow", 3);
 pref("browser.link.open_newwindow.restriction", 2);
 
 // Tabbed browser
-//@line 377 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 375 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.tabs.autoHide", false);
-//@line 381 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 379 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.tabs.closeWindowWithLastTab", true);
 pref("browser.tabs.insertRelatedAfterCurrent", true);
 pref("browser.tabs.warnOnClose", true);
@@ -371,9 +369,9 @@ pref("browser.bookmarks.max_backups",             10);
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
 pref("javascript.options.showInConsole",          true);
-//@line 429 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 427 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
-//@line 434 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 432 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // This is the pref to control the location bar, change this to true to 
 // force this - this makes the origin of popup windows more obvious to avoid
@@ -433,10 +431,10 @@ pref("browser.gesture.swipe.left", "Browser:BackOrBackDuplicate");
 pref("browser.gesture.swipe.right", "Browser:ForwardOrForwardDuplicate");
 pref("browser.gesture.swipe.up", "cmd_scrollTop");
 pref("browser.gesture.swipe.down", "cmd_scrollBottom");
-//@line 497 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 495 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.latched", false);
 pref("browser.gesture.pinch.threshold", 25);
-//@line 500 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 498 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.out", "");
 pref("browser.gesture.pinch.in", "");
 pref("browser.gesture.pinch.out.shift", "");
@@ -448,7 +446,7 @@ pref("browser.gesture.twist.left", "");
 pref("browser.gesture.tap", "cmd_fullZoomReset");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 525 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 523 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -458,16 +456,11 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 535 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 533 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
 
-pref("profile.allow_automigration", false);   // setting to false bypasses automigration in the profile code
-
-// Customizable toolbar stuff
-pref("custtoolbar.personal_toolbar_folder", "");
-
 // pref to control the alert notification 
 pref("alerts.slideIncrement", 1);
 pref("alerts.slideIncrementTime", 10);
@@ -519,16 +512,16 @@ pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
 pref("plugins.hide_infobar_for_missing_plugin", false);
 pref("plugins.hide_infobar_for_outdated_plugin", false);
 
-//@line 598 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 591 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 pref("plugins.update.url", "https://www.mozilla.com/%LOCALE%/plugincheck/");
 pref("plugins.update.notifyUser", false);
 
-//@line 605 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 598 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 610 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 603 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 612 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 605 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -537,9 +530,9 @@ pref("browser.download.hide_plugins_without_extensions", true);
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 621 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 614 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 625 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 618 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -628,7 +621,7 @@ pref("gecko.handlerService.schemes.ircs.3.uriTemplate", "chrome://browser-region
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 714 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 707 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", true);
 
@@ -672,27 +665,27 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 763 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 756 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 766 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 759 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("urlclassifier.updatecachemax", 104857600);
-//@line 770 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 763 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 775 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 768 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 pref("browser.EULA.version", 3);
 pref("browser.rights.version", 3);
 pref("browser.rights.3.shown", false);
 
-//@line 784 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 777 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
-//@line 788 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 781 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_from_crash", true);
-//@line 790 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 783 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_session_once", false);
 
 // minimal interval between two save operations in milliseconds
@@ -812,22 +805,22 @@ pref("browser.bookmarks.editDialog.firstEditField", "namePicker");
 pref("geo.wifi.uri", "https://www.google.com/loc/json");
 pref("geo.wifi.protocol", 0);
 
-//@line 941 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 934 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // Whether to use a panel that looks like an OS X sheet for customization
-//@line 946 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 939 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("toolbar.customization.usesheet", false);
-//@line 948 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 941 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
-//@line 959 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 952 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 pref("dom.ipc.plugins.enabled", true);
-//@line 963 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 954 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
-//@line 977 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 968 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
-//@line 979 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 970 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 // The sync engines to use.
 pref("services.sync.registerEngines", "Bookmarks,Form,History,Password,Prefs,Tab");
 // Preferences to be synced by default
@@ -902,7 +895,7 @@ pref("services.sync.prefs.sync.security.warn_viewing_mixed", true);
 pref("services.sync.prefs.sync.signon.rememberSignons", true);
 pref("services.sync.prefs.sync.spellchecker.dictionary", true);
 pref("services.sync.prefs.sync.xpinstall.whitelist.required", true);
-//@line 1054 "/home/karma/src/build/browser/app/profile/firefox.js"
+//@line 1045 "/home/karma/src/firefox5/build/browser/app/profile/firefox.js"
 
 // Disable the error console and inspector
 pref("devtools.errorconsole.enabled", false);
